/*
 * Copyright  1995, interface business GmbH, Dresden.
 *      All rights reserved.
 *
 * This code has been written by Jrg Wunsch, Dresden.
 * Direct comments to <joerg_wunsch@interface-business.de>.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR(S) ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 *      $Id: upsmon.h,v 1.3 1995/10/30 14:20:12 j Exp $
 */

#include <curses.h>
#include <sys/types.h>
#include <sys/time.h>
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <termios.h>
#include <string.h>

#include "smartups.h"

struct bargraph
{
  WINDOW *win;
  int len, digits;
  double unit, min, max;
  const char *fmt;
};

struct ups_status
{
  unsigned standby: 1;		/* UPS running stand-by */
  unsigned line_pwr_fail: 1;	/* no input line power */
  unsigned battery_low: 1;	/* battery is low */
  unsigned not_avail: 1;	/* status info not available */
};

/* main.c */
int ups_fd;

void
quit(int signo);

/* terminal.c */
void
terminal_init(const char *headline);

void
messagebox(int height, int width, int topy, int topx,
	   const char *msg, int sleep);

struct bargraph *
init_bargraph(int height, int width, int topy, int topx,
	      double min, double max, double step, const char *fmt,
	      const char *headline,
	      int digits, const char *fmt2);
void
update_bargraph(struct bargraph *bp, double volume);

void
del_bargraph(struct bargraph *bp);

void
message(const char *msg);

void
disp_status(struct ups_status s);


/* ups.c */
void
ups_init(const char *ttyname);

char *
ups_command(int cmd);

void
ups_reset(void);

struct ups_status
ups_read_stat(void);

double
ups_read_double(int cmd);

long
ups_read_int(int cmd);

